==> owncloud-app-calendar-1%3A1.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/calendar/l10n/en_GB.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Calendar",
    "Individual" : "Individual",
    "Group" : "Group",
    "Resource" : "Resource",
    "Room" : "Room",
    "Unknown" : "Unknown",
    "Required" : "Required",
    "Optional" : "Optional",
    "Does not attend" : "Does not attend",
    "New event" : "New event",
    "Attendees" : "Attendees",
    "Reminders" : "Reminders",
    "Repeating" : "Repeating",
    "When shared show full event" : "When shared show full event",
    "When shared show only busy" : "When shared show only busy",
    "When shared hide this event" : "When shared hide this event",
    "Please add a title!" : "Please add a title!",
    "Please select a calendar!" : "Please select a calendar!",
    "Global" : "Global",
    "None" : "None",
    "Every day" : "Every day",
    "Every week" : "Every week",
    "Every month" : "Every month",
    "Every year" : "Every year",
    "never" : "never",
    "after" : "after",
    "At time of event" : "At time of event",
    "5 minutes before" : "5 minutes before",
    "10 minutes before" : "10 minutes before",
    "15 minutes before" : "15 minutes before",
    "30 minutes before" : "30 minutes before",
    "1 hour before" : "1 hour before",
    "2 hours before" : "2 hours before",
    "Custom" : "Custom",
    "Audio" : "Audio",
    "E Mail" : "Email",
    "Pop up" : "Pop-up",
    "sec" : "sec",
    "min" : "min",
    "hours" : "hours",
    "days" : "days",
    "week" : "week",
    "before" : "before",
    "start" : "start",
    "end" : "end",
    "Editing reminders of uknown type not supported." : "Editing reminders of unknown type not supported.",
    "Week {number} of {year}" : "Week {number} of {year}",
    "Successfully imported" : "Successfully imported",
    "Partially imported, 1 failure" : "Partially imported, 1 failure",
    "Partially imported, {n} failures" : "Partially imported, {n} failures",
    "Audio alarm" : "Audio alarm",
    "Pop-up" : "Pop-up",
    "E-Mail" : "Email",
    "{type} {time} before the event starts" : "{type} {time} before the event starts",
    "{type} {time} before the event ends" : "{type} {time} before the event ends",
    "{type} {time} after the event starts" : "{type} {time} after the event starts",
    "{type} {time} after the event ends" : "{type} {time} after the event ends",
    "{type} at the event's start" : "{type} at the event's start",
    "{type} at the event's end" : "{type} at the event's end",
    "{type} at {time}" : "{type} at {time}",
    "{calendar} shared by {owner}" : "{calendar} shared by {owner}",
    "Title of the Event" : "Title of the Event",
    "starts" : "starts",
    "ends" : "ends",
    "All day Event" : "All day Event",
    "Location" : "Location",
    "Delete" : "Delete",
    "Cancel" : "Cancel",
    "More ..." : "More ...",
    "Create" : "Create",
    "Update" : "Update",
    "Close" : "Close",
    "Description" : "Description",
    "Export" : "Export",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature.",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option.",
    "Day" : "Day",
    "Week" : "Week",
    "Month" : "Month",
    "Today" : "Today",
    "Share Calendar" : "Share Calendar",
    "More" : "More",
    "Edit" : "Edit",
    "group" : "group",
    "New Calendar" : "New Calendar",
    "Subscriptions" : "Subscriptions",
    "New Subscription" : "New Subscription",
    "Url" : "URL",
    "Edit event" : "Edit event",
    "Delete Event" : "Delete Event",
    "Save Event" : "Save Event",
    "Time" : "Time",
    "Type" : "Type",
    "Relative" : "Relative",
    "Absolute" : "Absolute",
    "Repeat" : "Repeat",
    "times every" : "times every",
    "Add" : "Add",
    "E-Mail address of attendee" : "E-Mail address of attendee",
    "Please add your email address in the personal settings in order to add attendees." : "Please add your email address in the personal settings in order to add attendees.",
    "from" : "from",
    "to" : "to",
    "This event's repeating rule is not supported yet." : "This event's repeating rule is not supported yet.",
    "Support for advanced rules will be added with subsequent updates." : "Support for advanced rules will be added with subsequent updates.",
    "Reset repeating rule" : "Reset repeating rule",
    "Repeat every ..." : "Repeat every ...",
    "end repeat ..." : "end repeat ...",
    "times" : "times",
    "Import Calendars" : "Import Calendars",
    "Import canceled" : "Import cancelled",
    "Analyzing calendar" : "Analysing calendar",
    "The file contains objects incompatible with the selected calendar" : "The file contains objects incompatible with the selected calendar",
    "New calendar" : "New calendar",
    "Import scheduled" : "Import scheduled",
    "Settings" : "Settings",
    "Import calendar" : "Import calendar",
    "No Calendars selected for import" : "No Calendars selected for import",
    "Primary CalDAV address" : "Primary CalDAV address",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV address"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-app-calendar-1%3A1.2.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/calendar/l10n/en_GB.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Calendar",
    "Individual" : "Individual",
    "Group" : "Group",
    "Resource" : "Resource",
    "Room" : "Room",
    "Unknown" : "Unknown",
    "Required" : "Required",
    "Optional" : "Optional",
    "Does not attend" : "Does not attend",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "You are in an unknown timezone ({tz}), falling back to UTC",
    "Please create a calendar first." : "Please create a calendar first.",
    "New event" : "New event",
    "Attendees" : "Attendees",
    "Reminders" : "Reminders",
    "Repeating" : "Repeating",
    "When shared show full event" : "When shared show full event",
    "When shared show only busy" : "When shared show only busy",
    "When shared hide this event" : "When shared hide this event",
    "Please add a title!" : "Please add a title!",
    "Please select a calendar!" : "Please select a calendar!",
    "Global" : "Global",
    "None" : "None",
    "Every day" : "Every day",
    "Every week" : "Every week",
    "Every month" : "Every month",
    "Every year" : "Every year",
    "never" : "never",
    "after" : "after",
    "At time of event" : "At time of event",
    "5 minutes before" : "5 minutes before",
    "10 minutes before" : "10 minutes before",
    "15 minutes before" : "15 minutes before",
    "30 minutes before" : "30 minutes before",
    "1 hour before" : "1 hour before",
    "2 hours before" : "2 hours before",
    "Custom" : "Custom",
    "Audio" : "Audio",
    "E Mail" : "Email",
    "Pop up" : "Pop-up",
    "sec" : "sec",
    "min" : "min",
    "hours" : "hours",
    "days" : "days",
    "week" : "week",
    "before" : "before",
    "start" : "start",
    "end" : "end",
    "Editing reminders of uknown type not supported." : "Editing reminders of unknown type not supported.",
    "Week {number} of {year}" : "Week {number} of {year}",
    "Successfully imported" : "Successfully imported",
    "Partially imported, 1 failure" : "Partially imported, 1 failure",
    "Partially imported, {n} failures" : "Partially imported, {n} failures",
    "Audio alarm" : "Audio alarm",
    "Pop-up" : "Pop-up",
    "E-Mail" : "Email",
    "{type} {time} before the event starts" : "{type} {time} before the event starts",
    "{type} {time} before the event ends" : "{type} {time} before the event ends",
    "{type} {time} after the event starts" : "{type} {time} after the event starts",
    "{type} {time} after the event ends" : "{type} {time} after the event ends",
    "{type} at the event's start" : "{type} at the event's start",
    "{type} at the event's end" : "{type} at the event's end",
    "{type} at {time}" : "{type} at {time}",
    "{calendar} shared by {owner}" : "{calendar} shared by {owner}",
    "Title of the Event" : "Title of the Event",
    "starts" : "starts",
    "ends" : "ends",
    "All day Event" : "All day Event",
    "Location" : "Location",
    "Delete" : "Delete",
    "Cancel" : "Cancel",
    "More ..." : "More ...",
    "Create" : "Create",
    "Update" : "Update",
    "Close" : "Close",
    "Description" : "Description",
    "Export" : "Export",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature.",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option.",
    "Day" : "Day",
    "Week" : "Week",
    "Month" : "Month",
    "Today" : "Today",
    "Share Calendar" : "Share Calendar",
    "More" : "More",
    "Edit" : "Edit",
    "CalDAV" : "CalDAV",
    "group" : "group",
    "New Calendar" : "New Calendar",
    "Subscriptions" : "Subscriptions",
    "New Subscription" : "New Subscription",
    "Url" : "URL",
    "Edit event" : "Edit event",
    "Delete Event" : "Delete Event",
    "Save Event" : "Save Event",
    "Time" : "Time",
    "Type" : "Type",
    "Relative" : "Relative",
    "Absolute" : "Absolute",
    "Repeat" : "Repeat",
    "times every" : "times every",
    "Add" : "Add",
    "E-Mail address of attendee" : "E-Mail address of attendee",
    "Please add your email address in the personal settings in order to add attendees." : "Please add your email address in the personal settings in order to add attendees.",
    "from" : "from",
    "to" : "to",
    "This event's repeating rule is not supported yet." : "This event's repeating rule is not supported yet.",
    "Support for advanced rules will be added with subsequent updates." : "Support for advanced rules will be added with subsequent updates.",
    "Reset repeating rule" : "Reset repeating rule",
    "Repeat every ..." : "Repeat every ...",
    "end repeat ..." : "end repeat ...",
    "times" : "times",
    "Import Calendars" : "Import Calendars",
    "Import canceled" : "Import cancelled",
    "Analyzing calendar" : "Analysing calendar",
    "The file contains objects incompatible with the selected calendar" : "The file contains objects incompatible with the selected calendar",
    "New calendar" : "New calendar",
    "Import scheduled" : "Import scheduled",
    "Settings" : "Settings",
    "Import calendar" : "Import calendar",
    "No Calendars selected for import" : "No Calendars selected for import",
    "Primary CalDAV address" : "Primary CalDAV address",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV address"
},
"nplurals=2; plural=(n != 1);");
